@@ -5,7 +5,15 @@ import math
 
 import pytest
 
-from lyceum.repr import ascii2bin, bin2dec, bin2float, dec2bin, dec2hex, hex2dec
+from lyceum.repr import (
+    ascii2bin,
+    bin2ascii,
+    bin2dec,
+    bin2float,
+    dec2bin,
+    dec2hex,
+    hex2dec,
+)
 
 
 def test_bin():
@@ -25,6 +33,17 @@ def test_ascii2bin():
     assert ascii2bin("O", sep="_") == "0100_1111"
 
 
+def test_bin2ascii():
+    with pytest.raises(AssertionError):
+        # n'accepte que les octets
+        bin2ascii("001")
+    with pytest.raises(AssertionError):
+        # que de l'ascii
+        bin2ascii("100000000")
+
+    assert bin2ascii("01001010") == "J"
+
+
 def test_bin2float():
     # single float
     assert bin2float("0 01111111 00000000000000000000000") == 1
